<?php
/**
 * Frequently Searched Words List
 *
 * @author  Kazuya Takami
 * @version 2.1.0
 * @since   1.0.0
 */
class Frequently_Searched_Words_List {

	/**
	 * Variable definition: text domain
	 *
	 * @version 1.0.0
	 * @since   1.0.0
	 */
	private $text_domain;

	/**
	 * Constructor Define.
	 *
	 * @version 1.0.0
	 * @since   1.0.0
	 * @param   String $text_domain
	 */
	public function __construct ( $text_domain ) {
		$this->text_domain = $text_domain;

		$db   = new Frequently_Searched_Words_Admin_Db();
		$mode = "";

		if ( isset( $_GET['mode'] ) && $_GET['mode'] === 'delete' ) {
			if ( isset( $_GET['frequently_searched_words_id'] ) && is_numeric( $_GET['frequently_searched_words_id'] ) ) {
				$db->delete_options( $_GET['frequently_searched_words_id'] );
				$mode = "delete";
			}
		}

		$this->page_render( $db, $mode );
	}

	/**
	 * Settings Page HTML Render.
	 *
	 * @version 2.1.0
	 * @since   1.0.0
	 * @param   Frequently_Searched_Words_Admin_Db $db
	 * @param   String $mode
	 */
	private function page_render ( Frequently_Searched_Words_Admin_Db $db, $mode = "" ) {
		$self_url = $_SERVER['PHP_SELF'] . '?' . esc_html( $_SERVER['QUERY_STRING'] );

		$html  = '';
		$html .= '<div class="wrap">';
		$html .= '<h1>' . __( 'Frequently Searched Words List', $this->text_domain ) . '</h1>';
		echo $html;

		if ( $mode === "delete" ) {
			$this->information_render();
		}

		$html  = '<hr>';
		$html .= __( 'ShortCode', $this->text_domain ) . ' : ';
		$html .= '<input type="text" onfocus="this.select();" readonly="readonly" value="[wp-frequently-searched-words]" class="regular-text code">';
		$html .= '<p>' . __( 'ShortCode Params', $this->text_domain ) . ' : </p>';
		$html .= '<ul>';
		$html .= '<li>- id : e.g) id="example"</li>';
		$html .= '<li>- class : e.g) class="example"</li>';
		$html .= '<li>- limit : e.g) limit="5" (default: 10)</li>';
		$html .= '</ul>';
		$html .= '<table class="wp-list-table widefat fixed striped posts fsw-list-table">';
		$html .= '<tr>';
		$html .= '<th scope="row">&nbsp;</th>';
		$html .= '<th scope="row">No.</th>';
		$html .= '<th scope="row">' . esc_html__( 'Search Word',  $this->text_domain ) . '</th>';
		$html .= '<th scope="row">' . esc_html__( 'Search Count', $this->text_domain ) . '</th>';
		$html .= '<th scope="row">&nbsp;</th>';
		$html .= '</tr>';
		echo $html;

		/** DB table get list */
		$results = $db->get_list_options();

		if ( $results ) {
			$count_array = $db->get_search_count_sum();
			$count = 1;
			foreach ( $results as $row ) {
				$html  = '';
				$html .= '<tr>';
				$html .= '<td>';
				$html .= '<a href="' . $self_url . '&mode=delete&frequently_searched_words_id=' . esc_html( $row->id ) . '">';
				$html .= esc_html__( 'Delete', $this->text_domain );
				$html .= '<td>' . $count++ . '</td>';
				$html .= '</a>';
				$html .= '</td>';
				$html .= '<td>' . esc_html( $row->search_word )  . '</td>';
				$html .= '<td>' . esc_html( $row->search_count ) . '</td>';

				if ( isset( $count_array['SCOUNT'] ) && (int) $count_array['SCOUNT'] > 0 ) {
					$width = ( (int) $row->search_count / $count_array['SCOUNT'] ) * 100;
				} else {
					$width = 0;
				}

				$html .= '<td><span style="width: ' . $width . '%;">&nbsp;</span></td>';
				$html .= '</tr>';
				echo $html;
			}
		} else {
			echo '<td colspan="5">' . esc_html__( 'Without registration.', $this->text_domain ) . '</td>';
		}

		$html  = '</table>';
		$html .= '</div>';
		echo $html;
	}


	/**
	 * Information Message Render
	 *
	 * @version 1.0.0
	 * @since   1.0.0
	 */
	private function information_render () {
		$html  = '<div id="message" class="updated notice notice-success is-dismissible below-h2">';
		$html .= '<p>Deletion succeeds.</p>';
		$html .= '<button type="button" class="notice-dismiss">';
		$html .= '<span class="screen-reader-text">Dismiss this notice.</span>';
		$html .= '</button>';
		$html .= '</div>';

		echo $html;
	}
}